OC.L10N.register(
    "photos",
    {
    "Photos" : "Fotografias",
    "Your memories under your control" : "Is regordos tuos controllados",
    "Videos" : "Vìdeos",
    "Albums" : "Album",
    "People" : "Gente",
    "Folders" : "Cartellas",
    "Favorites" : "Preferidos",
    "Shared with you" : "Cumpartzidu cun tegus",
    "Tags" : "Etichetas",
    "Locations" : "Positziones",
    "Back" : "In segus",
    "Save" : "Sarva",
    "Open the full size \"{name}\" image" : "Aberi s'imàgine \"{name}\" a mannària prena",
    "Open the \"{name}\" sub-directory" : "Aberi sa sub-cartella \"{name}\"",
    "Back to {folder}" : "Torra a {folder}",
    "Share this folder" : "Cumpartzi custa cartella",
    "Enable squared photos view" : "Ativa sa visualizatzione a fotos cuadradas",
    "View" : "Visualiza",
    "An error occurred" : "B'at àpidu un'errore",
    "Favorite" : "Preferidu",
    "Remove from favorites" : "Boga·nche dae preferidos",
    "This folder does not exist" : "Custa cartella no esistit",
    "No photos in here" : "Peruna fotografia inoghe",
    "No tags yet" : "Ancora peruna eticheta",
    "Photos with tags will show up here" : "Is fotografias etichetadas ant a aparèssere inoghe",
    "Add" : "Agiunghe",
    "Download" : "Iscàrriga",
    "Delete selection" : "Cantzella seletzione",
    "Delete" : "Cantzella",
    "Tagged photos" : "Fotografias etichetadas",
    "Your photos" : "Is fotografias tuas",
    "Your videos" : "Is vìdeos tuos",
    "Your folders" : "Is cartellas tuas",
    "Settings" : "Impostatziones"
},
"nplurals=2; plural=(n != 1);");
